@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -65,8 +65,7 @@ int mutt_get_tmp_attachment (BODY *a)
   if((fpin = fopen(a->filename, "r")) && (fpout = safe_fopen(tempfile, "w")))
   {
     mutt_copy_stream (fpin, fpout);
-    FREE(&a->filename);
-    a->filename = safe_strdup(tempfile);
+    mutt_str_replace (&a->filename, tempfile);
     a->unlink = 1;
 
     if(a->stamp >= st.st_mtime)
