@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2000  Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it
  *     and/or modify it under the terms of the GNU General Public
@@ -88,7 +88,7 @@ static int edit_one_message (CONTEXT *ctx, HEADER *cur)
   if (stat (tmp, &sb) == 0)
     mtime = sb.st_mtime;
 
-  mutt_edit_file (Editor, tmp);
+  mutt_edit_file (NONULL (Visual), tmp);
 
   if ((rc = stat (tmp, &sb)) == -1)
   {
