@@ -79,8 +79,7 @@ void mutt_history_add (history_class_t hclass, const char *s)
     if (prev < 0) prev = HistSize - 1;
     if (!h->hist[prev] || mutt_strcmp (h->hist[prev], s) != 0)
     {
-      safe_free ((void **) &h->hist[h->last]);
-      h->hist[h->last++] = safe_strdup (s);
+      mutt_str_replace (&h->hist[h->last++], s);
       if (h->last > HistSize - 1)
 	h->last = 0;
     }
