@@ -653,20 +653,16 @@ static void mutt_restore_default (struct option_t *p)
   {
     case DT_STR:
       if (p->init)
-      {
-	FREE (p->data);
-	*((char **) p->data) = safe_strdup ((char *) p->init);
-      }
+	mutt_str_replace ((char **) p->data, (char *) p->init); 
       break;
     case DT_PATH:
       if (p->init)
       {
 	char path[_POSIX_PATH_MAX];
 
-	FREE (p->data);
 	strfcpy (path, (char *) p->init, sizeof (path));
 	mutt_expand_path (path, sizeof (path));
-	*((char **) p->data) = safe_strdup (path);
+	mutt_str_replace ((char **) p->data, path);
       }
       break;
     case DT_ADDR:
@@ -847,7 +843,14 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	     DTYPE (MuttVars[idx].type) == DT_PATH ||
 	     DTYPE (MuttVars[idx].type) == DT_ADDR)
     {
-      if (query || *s->dptr != '=')
+      if (unset)
+      {
+	if (DTYPE (MuttVars[idx].type) == DT_ADDR)
+	  rfc822_free_address ((ADDRESS **) MuttVars[idx].data);
+	else
+	  safe_free ((void **) MuttVars[idx].data);
+      }
+      else if (query || *s->dptr != '=')
       {
 	char _tmp[STRING];
 	char *val = NULL;
@@ -866,29 +869,31 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 		  NONULL (val));
 	break;
       }
-
-      s->dptr++;
-
-      /* copy the value of the string */
-      if (DTYPE (MuttVars[idx].type) == DT_ADDR)
-	rfc822_free_address ((ADDRESS **) MuttVars[idx].data);
-      else
-	FREE (MuttVars[idx].data);
-
-      mutt_extract_token (tmp, s, 0);
-      if (DTYPE (MuttVars[idx].type) == DT_PATH)
-      {
-	strfcpy (scratch, tmp->data, sizeof (scratch));
-	mutt_expand_path (scratch, sizeof (scratch));
-	*((char **) MuttVars[idx].data) = safe_strdup (scratch);
-      }
-      else if (DTYPE (MuttVars[idx].type) == DT_STR)
-      {
-	*((char **) MuttVars[idx].data) = safe_strdup (tmp->data);
-      }
       else
       {
-	*((ADDRESS **) MuttVars[idx].data) = rfc822_parse_adrlist (NULL, tmp->data);
+        s->dptr++;
+
+        /* copy the value of the string */
+        if (DTYPE (MuttVars[idx].type) == DT_ADDR)
+	  rfc822_free_address ((ADDRESS **) MuttVars[idx].data);
+        else
+	  FREE (MuttVars[idx].data);
+
+        mutt_extract_token (tmp, s, 0);
+        if (DTYPE (MuttVars[idx].type) == DT_PATH)
+        {
+	  strfcpy (scratch, tmp->data, sizeof (scratch));
+	  mutt_expand_path (scratch, sizeof (scratch));
+	  *((char **) MuttVars[idx].data) = safe_strdup (scratch);
+        }
+        else if (DTYPE (MuttVars[idx].type) == DT_STR)
+        {
+	  *((char **) MuttVars[idx].data) = safe_strdup (tmp->data);
+        }
+        else
+        {
+	  *((ADDRESS **) MuttVars[idx].data) = rfc822_parse_adrlist (NULL, tmp->data);
+        }
       }
     }
     else if (DTYPE(MuttVars[idx].type) == DT_RX)
@@ -1035,6 +1040,8 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
     else if (DTYPE(MuttVars[idx].type) == DT_NUM)
     {
       short *ptr = (short *) MuttVars[idx].data;
+      int val;
+      char *t;
 
       if (query || *s->dptr != '=')
       {
@@ -1046,7 +1053,16 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
       s->dptr++;
 
       mutt_extract_token (tmp, s, 0);
-      *ptr = (short) atoi (tmp->data);
+      val = strtol (tmp->data, &t, 0);
+
+      if (!*tmp->data || *t || (short) val != val)
+      {
+	snprintf (err->data, err->dsize, _("%s: invalid value"), tmp->data);
+	r = -1;
+	break;
+      }
+      else
+	*ptr = (short) val;
 
       /* these ones need a sanity check */
       if (mutt_strcmp (MuttVars[idx].option, "history") == 0)
@@ -1763,6 +1779,22 @@ void mutt_init (int skip_sys_rc, LIST *commands)
 
   mutt_init_history ();
 
+  
+  
+  
+  /*
+   * 
+   *			   BIG FAT WARNING
+   * 
+   * When changing the code which looks for a configuration file,
+   * please also change the corresponding code in muttbug.sh.in.
+   * 
+   * 
+   */
+  
+  
+  
+  
   if (!Muttrc)
   {
     snprintf (buffer, sizeof(buffer), "%s/.muttrc-%s", NONULL(Homedir), MUTT_VERSION);
