@@ -177,7 +177,7 @@ struct option_t MuttVars[] = {
   ** If set, Mutt will prompt you for carbon-copy (Cc) recipients before
   ** editing the body of an outgoing message.
   */  
-  { "attach_format",	DT_STR,  R_NONE, UL &AttachFormat, UL "%u%D%t%4n %T%.40d%> [%.7m/%.10M, %.6e%?C?, %C?, %s] " },
+  { "attach_format",	DT_STR,  R_NONE, UL &AttachFormat, UL "%u%D%I %t%4n %T%.40d%> [%.7m/%.10M, %.6e%?C?, %C?, %s] " },
   /*
   ** .pp
   ** This variable describes the format of the `attachment' menu.  The
@@ -188,6 +188,7 @@ struct option_t MuttVars[] = {
   ** %d      description
   ** %e      MIME content-transfer-encoding
   ** %f      filename
+  ** %I      disposition (I=inline, A=attachment)
   ** %m      major MIME type
   ** %M      MIME subtype
   ** %n      attachment number
@@ -548,7 +549,13 @@ struct option_t MuttVars[] = {
   ** entry when expanding the alias.  By default the regular expression is set
   ** to "^[^,]*" which will return the string up to the first "," encountered.
   ** If the GECOS field contains a string like "lastname, firstname" then you
-  ** should set the gecos_regexp=".*".
+  ** should set the gecos_mask=".*".
+  ** .pp
+  ** This can be useful if you see the following behavior: you address a e-mail
+  ** to user ID stevef whose full name is Steve Franklin.  If mutt expands 
+  ** stevef to "Franklin" stevef@foo.bar then you should set the gecos_mask to
+  ** a regular expression that will match the whole name so mutt will expand
+  ** "Franklin" to "Franklin, Steve".
   */
   { "hdr_format",	DT_SYN,  R_NONE, UL "index_format", 0 },
   /*
@@ -654,7 +661,7 @@ struct option_t MuttVars[] = {
   /*
   ** .pp
   ** Specifies the password for your IMAP account.  If unset, Mutt will
-  ** prompt you for your password when you invoke the fetch-mail function.
+  * prompt you for your password when you invoke the fetch-mail function.
   ** \fBWarning\fP: you should only use this option when you are on a
   ** fairly secure machine, because the superuser can read your muttrc even
   ** if you are the only one who can read the file.
@@ -1318,6 +1325,24 @@ struct option_t MuttVars[] = {
   ** be saved in this file and further connections are automatically 
   ** accepted.
   */
+  { "ssl_use_sslv2", DT_BOOL, R_NONE, OPTSSLV2, 1 },
+  /*
+  ** .pp
+  ** This variables specifies whether to attempt to use SSLv2 in the
+  ** SSL authentication process.
+  */
+  { "ssl_use_sslv3", DT_BOOL, R_NONE, OPTSSLV3, 1 },
+  /*
+  ** .pp
+  ** This variables specifies whether to attempt to use SSLv3 in the
+  ** SSL authentication process.
+  */
+  { "ssl_use_tlsv1", DT_BOOL, R_NONE, OPTTLSV1, 1 },
+  /*
+  ** .pp
+  ** This variables specifies whether to attempt to use TLSv1 in the
+  ** SSL authentication process.
+  */
 #endif
 
   { "pipe_split",	DT_BOOL, R_NONE, OPTPIPESPLIT, 0 },
@@ -1486,7 +1511,10 @@ struct option_t MuttVars[] = {
   /*
   ** .pp
   ** Controls whether or not you are prompted to recall postponed messages
-  ** when composing a new message.  Also see ``$postponed''
+  ** when composing a new message.  Also see ``$$postponed''.
+  ** .pp
+  ** Setting this variable to ``yes'' is not generally useful, and thus not
+  ** recommended.
   */
   { "record",		DT_PATH, R_NONE, UL &Outbox, UL "" },
   /*
@@ -1565,9 +1593,20 @@ struct option_t MuttVars[] = {
   { "rfc2047_parameters", DT_BOOL, R_NONE, OPTRFC2047PARAMS, 0 },
   /*
   ** .pp
-  ** When this variable is set, Mutt will decode RFC2047-encoded MIME 
-  ** parameters.  Note that this ues of RFC2047's encoding is illegal,
-  ** but actually in use.
+  ** When this variable is set, Mutt will decode RFC-2047-encoded MIME 
+  ** parameters. You want to set this variable when mutt suggests you
+  ** to save attachments to files named like this: 
+  ** =?iso-8859-1?Q?file=5F=E4=5F991116=2Ezip?=
+  ** .pp
+  ** When this variable is set interactively, the change doesn't have
+  ** the desired effect before you have changed folders.
+  ** .pp
+  ** Note that this use of RFC 2047's encoding is explicitly,
+  ** prohibited by the standard, but nevertheless encountered in the
+  ** wild.
+  ** Also note that setting this parameter will \fInot\fP have the effect 
+  ** that mutt \fIgenerates\fP this kind of encoding.  Instead, mutt will
+  ** unconditionally use the encoding specified in RFC 2231.
   */
   { "save_address",	DT_BOOL, R_NONE, OPTSAVEADDRESS, 0 },
   /*
