@@ -38,7 +38,8 @@
 #endif
 
 static const char *ReachingUs = N_("\
-To contact the developers, please mail to <mutt-dev@mutt.org>.\n");
+To contact the developers, please mail to <mutt-dev@mutt.org>.\n\
+To report a bug, please use the muttbug utility.\n");
 
 static const char *Notice = N_("\
 Copyright (C) 1996-2000 Michael R. Elkins and others.\n\
@@ -228,17 +229,16 @@ static void show_version (void)
 	"-USE_GNU_REGEX  "
 #endif
 
+	"\n"
+	
 #ifdef HAVE_COLOR
 	"+HAVE_COLOR  "
 #else
 	"-HAVE_COLOR  "
 #endif
 
-	);
-  puts (
-
 #ifdef _PGPPATH
-	"\n"
+
 #ifdef HAVE_PGP5
 	"+HAVE_PGP5  "
 #endif
@@ -396,8 +396,7 @@ int main (int argc, char **argv)
 	break;
 
       case 'F':
-	FREE (&Muttrc);
-	Muttrc = safe_strdup (optarg);
+	mutt_str_replace (&Muttrc, optarg);
 	break;
 
       case 'f':
