@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999   Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -842,7 +842,7 @@ static int print_it (int special, char *str, FILE *out, int docstat)
 	}
 	case SP_START_TAB:
 	{
-	  fputs ("\n.IP\n.DS\n.sp\n.ft RR\n.nf\n", out);
+	  fputs ("\n.IP\n.DS\n.sp\n.ft CR\n.nf\n", out);
 	  docstat |= D_TAB | D_NL;
 	  break;
 	}
