@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -403,8 +403,7 @@ void mutt_set_parameter (const char *attribute, const char *value, PARAMETER **p
   {
     if (mutt_strcasecmp (attribute, q->attribute) == 0)
     {
-      safe_free((void **) &q->value);
-      q->value = safe_strdup(value);
+      mutt_str_replace (&q->value, value);
       return;
     }
   }
@@ -1026,3 +1025,13 @@ int state_printf(STATE *s, const char *fmt, ...)
   
   return rv;
 }
+
+void mutt_display_sanitize (char *s)
+{
+  for (; *s; s++)
+  {
+    if (!IsPrint (*s))
+      *s = '?';
+  }
+}
+      
