@@ -1431,6 +1431,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
   int indicator = indexlen / 3; 	/* the indicator line of the PI */
   int old_PagerIndexLines;		/* some people want to resize it
   					 * while inside the pager... */
+  int oldcount = -1;
 
   if (!(flags & M_SHOWCOLOR))
     flags |= M_SHOWFLAT;
@@ -1481,10 +1482,27 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
     strcat (helpstr, buffer);
   }
 
+  if (Context)
+    oldcount = Context->msgcount;
+  
   while (ch != -1)
   {
     mutt_curs_set (0);
 
+    if (mutt_buffy_notify () && option (OPTBEEPNEW))
+      beep ();
+    else if (Context && Context->msgcount != oldcount)
+    {
+      if (Context && Context->msgcount > oldcount)
+      {
+	mutt_message (_("New mail in this mailbox."));
+	if (option (OPTBEEPNEW))
+	  beep ();
+	redraw |= REDRAW_STATUS;
+      }
+      oldcount = Context->msgcount;
+    }
+
     if (redraw & REDRAW_FULL)
     {
       SETCOLOR (MT_COLOR_NORMAL);
@@ -1677,7 +1695,8 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
     move (statusoffset, COLS-1);
     mutt_refresh ();
     ch = km_dokey (MENU_PAGER);
-    mutt_clear_error ();
+    if (ch != -1)
+      mutt_clear_error ();
     mutt_curs_set (1);
 
     if (SigInt)
