@@ -138,6 +138,7 @@ void mutt_create_alias (ENVELOPE *, ADDRESS *);
 void mutt_decode_attachment (BODY *, STATE *);
 void mutt_default_save (char *, size_t, HEADER *);
 void mutt_display_address (ENVELOPE *);
+void mutt_display_sanitize (char *);
 void mutt_edit_content_type (HEADER *, BODY *);
 void mutt_edit_file (const char *, const char *);
 void mutt_edit_headers (const char *, const char *, HEADER *, char *, size_t);
@@ -194,6 +195,7 @@ void mutt_shell_escape (void);
 void mutt_show_error (void);
 void mutt_signal_init (void);
 void mutt_stamp_attachment (BODY *a);
+void mutt_str_replace (char **p, const char *s);
 void mutt_tabs_to_spaces (char *);
 void mutt_tag_set_flag (int, int);
 void mutt_unblock_signals (void);
