@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -88,10 +88,7 @@ void mutt_update_tree (ATTACHPTR **idx, short idxlen)
     if (idx[x]->tree)
     {
       if (mutt_strcmp (idx[x]->tree, buf) != 0)
-      {
-	safe_free ((void **) &idx[x]->tree);
-	idx[x]->tree = safe_strdup (buf);
-      }
+	mutt_str_replace (&idx[x]->tree, buf);
     }
     else
       idx[x]->tree = safe_strdup (buf);
@@ -164,6 +161,7 @@ ATTACHPTR **mutt_gen_attach_list (BODY *m,
  * %d = description
  * %e = MIME content-transfer-encoding
  * %f = filename
+ * %I = content-disposition, either I (inline) or A (attachment)
  * %t = tagged flag
  * %m = major MIME type
  * %M = MIME subtype
@@ -278,6 +276,13 @@ const char *mutt_attach_fmt (char *dest,
 	snprintf (dest, destlen, fmt, ENCODING (aptr->content->encoding));
       }
       break;
+    case 'I':
+      if (!optional)
+      {
+	  snprintf (dest, destlen, "%c",
+		  (aptr->content->disposition == DISPINLINE) ? 'I' : 'A');
+      }
+      break;
     case 'm':
       if(!optional)
       {
