@@ -259,15 +259,13 @@ void rfc2047_encode_adrlist (ADDRESS *addr)
     if (ptr->personal)
     {
       rfc2047_encode_string (buffer, sizeof (buffer), (const unsigned char *)ptr->personal);
-      safe_free ((void **) &ptr->personal);
-      ptr->personal = safe_strdup (buffer);
+      mutt_str_replace (&ptr->personal, buffer);
     }
 #ifdef EXACT_ADDRESS
     if (ptr->val)
     {
       rfc2047_encode_string (buffer, sizeof (buffer), (const unsigned char *)ptr->val);
-      safe_free ((void **) &ptr->val);
-      ptr->val = safe_strdup (buffer);
+      mutt_str_replace (&ptr->val, buffer);
     }
 #endif
     ptr = ptr->next;
@@ -292,11 +290,8 @@ static int rfc2047_decode_word (char *d, const char *s, size_t len)
 	/* ignore language specification a la RFC 2231 */        
         if ((t = strchr (pp, '*')))
 	  *t = '\0';
-	if (mutt_strcasecmp (pp, Charset) != 0)
-        {
-	  filter = 1;
-	  charset = pp;
-	}
+        charset = pp;
+        filter = 1;
 	break;
       case 3:
 	if (toupper (*pp) == 'Q')
@@ -375,14 +370,10 @@ static int rfc2047_decode_word (char *d, const char *s, size_t len)
       CHARSET *chs = mutt_get_charset(Charset);
       mutt_decode_utf8_string(d, chs);
     }
-    else if (mutt_display_string(d, mutt_get_translation(charset, Charset)) == -1)
-    {
-      for(pd = d; *pd; pd++)
-      {
-        if (!IsPrint (*pd))
-	  *pd = '?';
-      }
-    }
+    else
+      mutt_display_string(d, mutt_get_translation(charset, Charset));
+
+    mutt_display_sanitize (d);
   }
   safe_free ((void **) &p);
   return (0);
