@@ -234,8 +234,7 @@ static int edit_envelope (ENVELOPE *en)
     mutt_message _("No subject, aborting.");
     return (-1);
   }
-  safe_free ((void **) &en->subject);
-  en->subject = safe_strdup (buf);
+  mutt_str_replace (&en->subject, buf);
 
   return 0;
 }
@@ -419,12 +418,12 @@ static int include_reply (CONTEXT *ctx, HEADER *cur, FILE *out)
   return 0;
 }
 
-static int default_to (ADDRESS **to, ENVELOPE *env, int group)
+static int default_to (ADDRESS **to, ENVELOPE *env, int flags)
 {
   char prompt[STRING];
   int i = 0;
 
-  if (group && env->mail_followup_to)
+  if (flags && env->mail_followup_to)
   {
     snprintf (prompt, sizeof (prompt), _("Follow-up to %s%s?"),
 	      env->mail_followup_to->mailbox,
@@ -437,6 +436,12 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
     }
   }
 
+  /* Exit now if we're setting up the default Cc list for list-reply
+   * (only set if Mail-Followup-To is present and honoured).
+   */
+  if (flags & SENDLISTREPLY)
+    return 0;
+
   if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from))
   {
     /* mail is from the user, assume replying to recipients */
@@ -496,6 +501,10 @@ int mutt_fetch_recips (ENVELOPE *out, ENVELOPE *in, int flags)
     tmp = find_mailing_lists (in->to, in->cc);
     rfc822_append (&out->to, tmp);
     rfc822_free_address (&tmp);
+
+    if (in->mail_followup_to &&
+        default_to (&out->cc, in, flags & SENDLISTREPLY) == -1)
+      return (-1); /* abort */
   }
   else
   {
@@ -914,8 +923,7 @@ static void encode_descriptions (BODY *b)
     if (t->description)
     {
       rfc2047_encode_string (tmp, sizeof (tmp), (unsigned char *) t->description);
-      safe_free ((void **) &t->description);
-      t->description = safe_strdup (tmp);
+      mutt_str_replace (&t->description, tmp);
     }
     if (t->parts)
       encode_descriptions (t->parts);
@@ -1030,6 +1038,7 @@ ci_send_message (int flags,		/* send mode */
     msg->content->subtype = safe_strdup ("plain");
     msg->content->unlink = 1;
     msg->content->use_disp = 0;
+    msg->content->disposition = DISPINLINE;
     
     if (!tempfile)
     {
